.. Django Audit Tools documentation master file, created by
   sphinx-quickstart on Thu Aug  7 13:00:34 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Audit Tools
=============================

Installation
------------
.. toctree::
   :maxdepth: 2

   installation.rst
   configuration.rst

Audit
-----
.. toctree::
   :maxdepth: 2

   Signals<audit/signals.rst>
   Models<audit/models.rst>
   Middleware<audit/middleware.rst>
   Managers<audit/managers.rst>
   Commands<audit/commands.rst>

Additional information
----------------------
.. toctree::
   :maxdepth: 2

   customproviders.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

